PoolState

Struct PoolState 

pub struct PoolState {
    pub max_size: Option<usize>,
    pub size: Option<usize>,
    pub idle: Option<usize>,
    pub in_use: Option<usize>,
    pub min_idle: Option<usize>,
    pub max_idle: Option<usize>,
}
State of a pool object.

If pool type doesn’t support some metrics, these metrics must be left as None.

Fields

max_size: Option<usize>

Maximum total (idle + in_use) number of resources in the pool.

size: Option<usize>

Current total (idle + in_use) number of resources in the pool.

idle: Option<usize>

Current number of idle (not acquired) resources.

in_use: Option<usize>

Current number of in-use (acquired) resources.

min_idle: Option<usize>

Minimum number of idle resources to keep in the pool.

max_idle: Option<usize>

Maximum number of idle resources to keep in the pool.